@@ -49,8 +49,8 @@ def set_brightness(
     method: Optional[str] = None,
     force: bool = False,
     verbose_error: bool = False,
-    no_return: bool = False
-) -> Union[List[int], int, None]:
+    no_return: bool = True
+) -> Union[None, List[int], int]:
     '''
     Sets the screen brightness
 
@@ -65,12 +65,12 @@ def set_brightness(
             If True, this check is bypassed
         verbose_error (bool): boolean value controls the amount of detail error messages will contain
         no_return (bool): if False, this function returns new brightness (by calling `get_brightness`).
-            If True, this function returns None. In the future this function will return `None` by default
+            If True, this function returns None (default behaviour).
 
     Returns:
-        list: list of ints (0 to 100)
-        int: if only one display is affected
-        None: if the `no_return` kwarg is specified
+        None: if the `no_return` kwarg is `True`
+        list: list of ints (0 to 100) only if the `no_return` kwarg is `False`
+        int: if only one display is affected and the `no_return` kwarg is `False`
 
     Example:
         ```python
@@ -197,7 +197,12 @@ def fade_brightness(
             )}
         )
     except (IndexError, LookupError) as e:
-        raise ScreenBrightnessError(f'\n\tfilter_monitors -> {type(e).__name__}: {e}')
+        if type(e) == LookupError and platform.system() == 'Linux' and method is None:
+            # if a user ONLY has XBacklight installed and no method was specified
+            # then filter_monitors will raise a LookupError
+            available_monitors = [method.XBacklight]
+        else:
+            raise ScreenBrightnessError(f'\n\tfilter_monitors -> {type(e).__name__}: {e}')
     except ValueError as e:
         if platform.system() == 'Linux' and (str(kwargs.get('method', '')).lower() == 'xbacklight'):
             available_monitors = [method.XBacklight]
@@ -613,7 +618,7 @@ class Monitor():
             if value is not None:
                 return key, value
 
-    def set_brightness(self, value: int, no_return: bool = False) -> Union[int, None]:
+    def set_brightness(self, value: int, no_return: bool = True) -> Union[None, int]:
         '''
         Sets the brightness for this display. See `set_brightness` for the full docs
 
@@ -623,8 +628,8 @@ class Monitor():
                 Otherwise it returns the result of `Monitor.get_brightness`
 
         Returns:
-            int: from 0 to 100
             None: if `no_return==True`
+            int: from 0 to 100
 
         Example:
             ```python
@@ -916,6 +921,7 @@ def __brightness(
                 if meta_method == 'set':
                     monitor['method'].set_brightness(*args, display=monitor['index'], **kwargs)
                     if no_return:
+                        output.append(None)
                         continue
 
                 output.append(monitor['method'].get_brightness(display=monitor['index'], **kwargs))
@@ -925,12 +931,21 @@ def __brightness(
 
     output = flatten_list(output)
 
-    if output and not set(output) == {None}:
-        # if all of the outputs are None then all of the monitors failed
-        output = output[0] if len(output) == 1 else output
-        return output if not no_return else None
-    elif meta_method == 'set' and no_return:
-        return
+    if output:
+        output_is_none = set(output) == {None}
+        if (
+            # can't have None output if we are trying to get the brightness
+            (meta_method == 'get' and not output_is_none)
+            or (
+                # if we are setting the brightness then we CAN have a None output
+                # but only if no_return is True.
+                meta_method == 'set'
+                and ((no_return and output_is_none) or not output_is_none)
+            )
+        ):
+            if no_return:
+                return
+            return output[0] if len(output) == 1 else output
 
     # if the function hasn't returned then it has failed
     msg = '\n'
@@ -1005,5 +1020,5 @@ else:
     raise NotImplementedError(f'{plat} is not yet supported')
 del(plat)
 
-__version__ = '0.9.0'
+__version__ = '0.10.0'
 __author__ = 'Crozzers'
